@@ -74,11 +74,6 @@ def syncify_async_function(async_func):
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
 
-    # if loop is None or not loop.is_running():
-    #     print("loop is none")
-    #     loop = asyncio.new_event_loop()
-    #     asyncio.set_event_loop(loop)
-
     def sync_func(*args, **kwargs):
         if not loop.is_running():
             loop.run_until_complete(asyncio.sleep(0))
@@ -173,8 +168,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             video = self.getPiH264Relay(id)
             audio = None
-            loop = asyncio.new_event_loop()
-            asyncio.set_event_loop(loop)
 
             transceiver = pc.addTransceiver("video", direction="sendonly")
 
@@ -224,8 +217,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
             asyncio.run(create_and_set_local_description(pc))
-            loop.close()
-            # syncify_async_function(create_and_set_local_description(pc))
 
             self.sio.emit("watcher", {"target": description,
                                       "id": id,
@@ -247,16 +238,18 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     async def setremotedescription(pc):
                         await self.peerConnections[id].setRemoteDescription(answer)
 
-                    syncify_async_function(setremotedescription)
+                    syncify_async_function(setremotedescription())
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
-                loop = asyncio.new_event_loop()
-                asyncio.set_event_loop(loop)
-                loop.run_until_complete(asyncio.run(self.peerConnections[id].close()))
-                loop.close()
+
+                async def closeconnection():
+                    await self.peerConnections[id].close()
+
+                syncify_async_function(closeconnection())
+
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
